@@ -5,7 +5,19 @@ import pandas as pd
 
 from .types import PyStvError, RaceInfo, RaceMetadata
 
-QUESTION_PATTERN = re.compile(r"(?P<question>.*) \[(?P<option>.*)\]")
+# The Google Form header pattern is the text of the question followed by the option in
+# brackets. An optional parenthetical indicating the number of winners is allowed in
+# between the question and the option.
+# Examples:
+#   What is your favorite season? [Spring]
+#   City Council (4 winners) [Darth Vader]
+#   Mayor (1 winner) [Luke Skywalker]
+QUESTION_PATTERN = re.compile(
+    r"^(?P<question>.*?)"
+    r"(\s+\((?P<num_winners>\d+)\s+winners?\))?"
+    r"\s*? "
+    r"\[(?P<option>.*)\]$"
+)
 
 
 def parse_google_form_csv(buffer):
@@ -30,19 +42,22 @@ def parse_header(header):
 
     questions = []
     options = []
+    num_winners_list = []
     starts = []
     ends = []
     for col_idx, col in enumerate(header):
         match = QUESTION_PATTERN.match(col)
         if match:
-            question = match.group("question")
-            option = match.group("option")
+            question = match.group("question").strip()
+            num_winners = match.group("num_winners") or 1
+            option = match.group("option").strip()
             if question != current_question:
                 if current_question is not None:
                     ends.append(col_idx)
                     options.append(current_options)
                     current_options = []
                 questions.append(question)
+                num_winners_list.append(int(num_winners))
                 starts.append(col_idx)
                 current_question = question
             current_options.append(option)
@@ -63,8 +78,8 @@ def parse_header(header):
     assert len(ends) == num_questions, ends
 
     return [
-        (RaceMetadata(q, 1, o), slice(s, e))
-        for q, o, s, e in zip(questions, options, starts, ends)
+        (RaceMetadata(q, w, o), slice(s, e))
+        for q, w, o, s, e in zip(questions, num_winners_list, options, starts, ends)
     ]
 
 
