@@ -73,7 +73,10 @@ def create_sankey_fig(df_nodes, df_links):
             target=df_links["target"],
             value=df_links["value"],
             color=df_links["color"],
-            customdata=df_links["round"],
+            # For display, add 2 to round:
+            # - add 1 because it is the next round that the transfers are counted
+            # - add 1 to start indexing from 1 (real people do not like 0-indexing)
+            customdata=df_links["round"] + 2,
             hovertemplate=(
                 "%{value:.0d} votes transferred<br />"
                 "from %{source.label} to %{target.label}<br />"
@@ -84,15 +87,6 @@ def create_sankey_fig(df_nodes, df_links):
     )
 
     fig = go.Figure(data=[sankey])
-    fig.add_annotation(
-        x=0,
-        y=-0.2,
-        xref="paper",
-        yref="paper",
-        align="left",
-        showarrow=False,
-        font_size=15,
-    )
     fig.update_layout(
         margin=dict(l=0, t=0),
     )
