@@ -17,18 +17,22 @@ def test_results_to_sankey():
     )
     df_nodes, df_links = pystv.result_to_sankey_data(race_result)
 
+    node_colors = (["rgba(0,0,0,0)"] + pystv.NODE_PALETTE[1:4]) * 3
     df_nodes_desired = pd.DataFrame(
         {
+            "round": [0, 0, 0, 0, 1, 1, 1, 1, 2, 2, 2, 2],
             "id": [0, 1, 2, 3, 0, 1, 2, 3, 0, 1, 2, 3],
-            "label": (["-- exhausted --"] + names) * 3,
+            "label": ([""] + names) * 3,
+            "color": node_colors,
         }
     )
     df_links_desired = pd.DataFrame(
         {
-            "id": [1, 2, 2, 3, 1, 2, 3],
+            "round": [0, 0, 0, 0, 1, 1, 1],
             "source": [1, 2, 2, 3, 5, 6, 7],
             "target": [5, 5, 6, 7, 11, 10, 11],
             "value": [2, 1, 4, 3, 3, 4, 3],
+            "color": [pystv.LINK_PALETTE[i] for i in [1, 2, 2, 3, 1, 2, 3]],
         }
     )
 
